@@ -9,7 +9,7 @@ use Carp;
 use Language::Chef::Ingredient;
 
 use vars qw/$VERSION/;
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 sub new {
    my $proto = shift;
@@ -258,12 +258,13 @@ Please see L<Language::Chef>;
 
 =head1 AUTHOR
 
-Steffen Mueller
+Steffen Mueller.
+
 Chef designed by David Morgan-Mar.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 Steffen Mueller. All rights reserved. This program is
+Copyright (c) 2002-2003 Steffen Mueller. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
@@ -271,4 +272,3 @@ Author can be reached at chef-module at steffen-mueller dot net
 
 =cut
 
-
